package auth

import (
	"testing"

	"forge.grandlyon.com/systemes-dinformation/project-template/sdk-go/pkg/tester"
)

var noH = tester.Header{Key: "", Value: ""}

func TestCheckUserHasRole(t *testing.T) {
	type args struct {
		user         TokenData
		allowedRoles []string
	}
	tests := []struct {
		name    string
		args    args
		wantErr bool
	}{
		{"has_one_role", args{user: TokenData{User: User{Role: "role01"}}, allowedRoles: []string{"role01", "role02"}}, false},
		{"has_not_role", args{user: TokenData{User: User{Role: "role03"}}, allowedRoles: []string{"role01", "role02"}}, true},
		{"user_roles_are_empty", args{user: TokenData{User: User{Role: ""}}, allowedRoles: []string{"role01", "role02"}}, true},
		{"allowed_roles_are_empty", args{user: TokenData{User: User{Role: "role01"}}, allowedRoles: []string{}}, true},
		{"all_roles_are_empty", args{user: TokenData{User: User{Role: ""}}, allowedRoles: []string{}}, true},
	}
	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			if err := checkUserHasRole(tt.args.user, tt.args.allowedRoles); (err != nil) != tt.wantErr {
				t.Errorf("checkUserHasRole() error = %v, wantErr %v", err, tt.wantErr)
			}
		})
	}
}

func TestMatchUser(t *testing.T) {
	// existingUser := User{ID: 2, Login: "Bakery", Role: "CLIENT", PasswordHash: "$2a$10$PgiAoLxZhgNtr7kRK/DH5ezwT./7vRkWqFNEtJD1670z3Zf60HqgG"}
	// veryLongString, _ := common.GenerateRandomString(10000)
	// specialCharString := "\""

	// type args struct {
	// 	sentUser User
	// }
	// tests := []struct {
	// 	name    string
	// 	args    args
	// 	want    User
	// 	wantErr bool
	// }{
	// 	{"user_exists", args{User{Login: "Bakery", Password: "password"}}, existingUser, false},
	// 	{"user_does_not_exists", args{User{Login: "notuser", Password: "password"}}, User{}, true},
	// 	{"user_does_not_exists_and_wrong_password", args{User{Login: "notuser", Password: "wrongpassword"}}, User{}, true},
	// 	{"wrong_password", args{User{Login: "Bakery", Password: "wrongpassword"}}, User{}, true},
	// 	{"no_password", args{User{Login: "Bakery", Password: ""}}, User{}, true},
	// 	{"empty_user", args{User{Login: "", Password: "password"}}, User{}, true},
	// 	{"empty_user_and_password", args{User{Login: "", Password: ""}}, User{}, true},
	// 	{"very_long_string_as_user", args{User{Login: veryLongString, Password: "password"}}, User{}, true},
	// 	{"very_long_string_as_password", args{User{Login: "Bakery", Password: veryLongString}}, User{}, true},
	// 	{"very_long_string_as_user_and_password", args{User{Login: veryLongString, Password: veryLongString}}, User{}, true},
	// 	{"special_char_string_as_user", args{User{Login: specialCharString, Password: "password"}}, User{}, true},
	// 	{"special_char_string_as_password", args{User{Login: "Bakery", Password: specialCharString}}, User{}, true},
	// 	{"special_char_string_as_user_and_password", args{User{Login: specialCharString, Password: specialCharString}}, User{}, true},
	// }
	// os.Mkdir("data", os.ModePerm)
	// os.Link("../../data/users.db", "./data/users.db")
	// for _, tt := range tests {
	// 	t.Run(tt.name, func(t *testing.T) {
	// 		got, err := NewDataHandler().MatchUser(tt.args.sentUser)
	// 		if (err != nil) != tt.wantErr {
	// 			t.Errorf("MatchUser() error = %v, wantErr %v", err, tt.wantErr)
	// 			return
	// 		}
	// 		if !reflect.DeepEqual(got, tt.want) {
	// 			t.Errorf("MatchUser() = %v, want %v", got, tt.want)
	// 		}
	// 	})
	// }
}
